#!/usr/bin/env node

const fs = require('fs');
const argv = require('minimist')(process.argv.slice(1));

let settings = {
    packageLocation: 'package.json',
    configXmlLocation: 'config.xml',
    jsonSpacing: 2
}

const throwError = (message) => {
    console.error(message);
    throw message;
}

const init  = () => {
    if (!fs.existsSync(settings.packageLocation)) {
        throwError('This project has no package.json!');
    }
    const packageJson = JSON.parse(fs.readFileSync(settings.packageLocation, 'utf8'));
    if (!packageJson.scripts) {
        packageJson.scripts = {};
    }
    if (packageJson.scripts.version) {
        packageJson.scripts.version = `ncvs version && ${packageJson.scripts.verison}`;
    } else {
        packageJson.scripts.version = `ncvs version`;
    }
    fs.writeFileSync(settings.packageLocation, JSON.stringify(packageJson, null, settings.jsonSpacing));
    console.log('Automatic versioning added to the project!');
}

const version = () => {
    if (!fs.existsSync(settings.packageLocation)) {
        throwError(`This project is not versioned with npm! (can not find ${settings.packageLocation})`);
    } 
    if (!fs.existsSync(settings.configXmlLocation)) {
        throwError(`This project is not a Cordova project! (can not find ${settings.configXmlLocation})`);
    }
    const widgetRegex = /<widget[\s\S]*?>/;
    const npmVersion = JSON.parse(fs.readFileSync(settings.packageLocation, 'utf8')).version;
    const rawXml = fs.readFileSync(settings.configXmlLocation, 'utf8');
    const widget = rawXml.match(widgetRegex)[0];
    const xmlHalves = rawXml.split(widget);
    const widgetHalves = widget.split(/version="[\s\S]*?"/);
    const newWidget = widgetHalves.join(`version="${npmVersion}"`);
    const newXml = xmlHalves.join(newWidget);
    fs.writeFileSync(settings.configXmlLocation, newXml);
    console.log(`${settings.configXmlLocation} updated to version ${npmVersion}!`)
} 

const funcs = {
    'init': init,
    'i': init,
    'version': version,
    'v': version
}

settings = Object.assign(settings, argv);

argv['_'].forEach((func) => {
    console.log(func, funcs.hasOwnProperty(func))
    if (funcs.hasOwnProperty(func)){
        funcs[func](argv);
    }
});



